@@ -78,7 +78,7 @@ func (c *command) validArgs(cmd *cobra.Command, args []string) []string {
 		return nil
 	}
 
-	return pcmd.AutocompleteApiKeys(c.EnvironmentId(), c.V2Client)
+	return pcmd.AutocompleteApiKeys(c.V2Client)
 }
 
 func (c *command) getAllUsers() ([]*ccloudv1.User, error) {
@@ -137,7 +137,11 @@ func (c *command) resolveResourceId(cmd *cobra.Command, v2Client *ccloudv2.Clien
 		clusterId = cluster.ID
 		apiKey = cluster.APIKey
 	case presource.KsqlCluster:
-		cluster, err := v2Client.DescribeKsqlCluster(resource, c.EnvironmentId())
+		environmentId, err := c.EnvironmentId()
+		if err != nil {
+			return "", "", "", err
+		}
+		cluster, err := v2Client.DescribeKsqlCluster(resource, environmentId)
 		if err != nil {
 			return "", "", "", errors.CatchResourceNotFoundError(err, resource)
 		}
