@@ -4,7 +4,6 @@ import (
 	"context"
 	"fmt"
 	"os"
-	"strconv"
 	"strings"
 	"time"
 
@@ -13,16 +12,13 @@ import (
 	"github.com/swaggest/go-asyncapi/reflector/asyncapi-2.4.0"
 	"github.com/swaggest/go-asyncapi/spec-2.4.0"
 
-	kafkarestv3 "github.com/confluentinc/ccloud-sdk-go-v2/kafkarest/v3"
 	ckgo "github.com/confluentinc/confluent-kafka-go/kafka"
 	schemaregistry "github.com/confluentinc/schema-registry-sdk-go"
 
 	"github.com/confluentinc/cli/internal/cmd/kafka"
 	sr "github.com/confluentinc/cli/internal/cmd/schema-registry"
-	"github.com/confluentinc/cli/internal/pkg/ccstructs"
 	pcmd "github.com/confluentinc/cli/internal/pkg/cmd"
 	v1 "github.com/confluentinc/cli/internal/pkg/config/v1"
-	dynamicconfig "github.com/confluentinc/cli/internal/pkg/dynamic-config"
 	"github.com/confluentinc/cli/internal/pkg/errors"
 	"github.com/confluentinc/cli/internal/pkg/kafkarest"
 	"github.com/confluentinc/cli/internal/pkg/log"
@@ -34,14 +30,8 @@ type command struct {
 	*pcmd.AuthenticatedStateFlagCommand
 }
 
-type Configs struct {
-	CleanupPolicy                  string `json:"cleanup.policy"`
-	DeleteRetentionMs              int    `json:"delete.retention.ms"`
-	ConfluentValueSchemaValidation string `json:"confluent.value.schema.validation"`
-}
-
 type confluentBinding struct {
-	Configs Configs `json:"x-configs"`
+	Configs map[string]string `json:"x-configs"`
 }
 
 type bindings struct {
@@ -69,7 +59,9 @@ const protobufErrorMessage string = "protobuf is not supported"
 func newExportCommand(prerunner pcmd.PreRunner) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "export",
-		Short: "Create an AsyncAPI specification for a Kafka cluster.",
+		Short: "Export an AsyncAPI specification.",
+		Long:  "Export an AsyncAPI specification for a Kafka cluster and Schema Registry.",
+		Args:  cobra.NoArgs,
 	}
 
 	c := &command{AuthenticatedStateFlagCommand: pcmd.NewAuthenticatedStateFlagCommand(cmd, prerunner)}
@@ -154,14 +146,13 @@ func (c *command) export(cmd *cobra.Command, _ []string) error {
 		return err
 	}
 	if err := c.countAsyncApiUsage(accountDetails); err != nil {
-		return err
+		log.CliLogger.Debug(err)
 	}
 	output.Printf("AsyncAPI specification written to \"%s\".\n", flags.file)
 	return os.WriteFile(flags.file, yaml, 0644)
 }
 
 func (c *command) getChannelDetails(details *accountDetails, flags *flags) error {
-	output.Printf("Adding operation: %s\n", details.channelDetails.currentTopic.GetTopicName())
 	err := details.getSchemaDetails()
 	if err != nil {
 		if err.Error() == protobufErrorMessage {
@@ -170,7 +161,7 @@ func (c *command) getChannelDetails(details *accountDetails, flags *flags) error
 		return fmt.Errorf("failed to get schema details: %v", err)
 	}
 	if err := details.getTags(); err != nil {
-		log.CliLogger.Warnf("failed to get tags: %v", err)
+		log.CliLogger.Warnf("Failed to get tags: %v", err)
 	}
 	details.channelDetails.example = nil
 	if flags.consumeExamples {
@@ -179,18 +170,19 @@ func (c *command) getChannelDetails(details *accountDetails, flags *flags) error
 			log.CliLogger.Warn(err)
 		}
 	}
-	details.channelDetails.bindings, err = c.getBindings(details.cluster, details.channelDetails.currentTopic)
+	details.channelDetails.bindings, err = c.getBindings(details.clusterId, details.channelDetails.currentTopic.GetTopicName())
 	if err != nil {
-		log.CliLogger.Warnf("bindings not found: %v", err)
+		log.CliLogger.Warnf("Bindings not found: %v", err)
 	}
 	if err := details.getTopicDescription(); err != nil {
-		log.CliLogger.Warnf("failed to get topic description: %v", err)
+		log.CliLogger.Warnf("Failed to get topic description: %v", err)
 	}
 	// x-messageCompatibility
 	details.channelDetails.mapOfMessageCompat, err = getMessageCompatibility(details.srClient, details.srContext, details.channelDetails.currentSubject)
 	if err != nil {
-		log.CliLogger.Warnf("failed to get subject's compatibility type")
+		log.CliLogger.Warnf("Failed to get subject's compatibility type: %v", err)
 	}
+	output.Printf("Added topic \"%s\".\n", details.channelDetails.currentTopic.GetTopicName())
 	return nil
 }
 
@@ -234,7 +226,7 @@ func getValueFormat(contentType string) string {
 
 func handlePanic() {
 	if err := recover(); err != nil {
-		log.CliLogger.Warn("failed to get message example: ", err)
+		log.CliLogger.Warnf("Failed to get message example: %v", err)
 	}
 }
 
@@ -285,35 +277,20 @@ func (c command) getMessageExamples(consumer *ckgo.Consumer, topicName, contentT
 	return jsonMessage, nil
 }
 
-func (c *command) getBindings(cluster *ccstructs.KafkaCluster, topicDescription kafkarestv3.TopicData) (*bindings, error) {
+func (c *command) getBindings(clusterId, topicName string) (*bindings, error) {
 	kafkaREST, err := c.GetKafkaREST()
 	if err != nil {
 		return nil, err
 	}
-	configs, err := kafkaREST.CloudClient.ListKafkaTopicConfigs(cluster.GetId(), topicDescription.GetTopicName())
+	configs, err := kafkaREST.CloudClient.ListKafkaTopicConfigs(clusterId, topicName)
 	if err != nil {
 		return nil, err
 	}
-	var cleanupPolicy string
-	deleteRetentionMsValue := -1
+	configsMap := make(map[string]string)
 	for _, config := range configs.Data {
-		if config.Name == "cleanup.policy" {
-			cleanupPolicy = config.GetValue()
-		}
-		if config.Name == "delete.retention.ms" {
-			deleteRetentionMsValue, err = strconv.Atoi(config.GetValue())
-			if err != nil {
-				return nil, err
-			}
-		}
-	}
-	var channelBindings any = confluentBinding{
-		Configs: Configs{
-			CleanupPolicy:                  cleanupPolicy,
-			DeleteRetentionMs:              deleteRetentionMsValue,
-			ConfluentValueSchemaValidation: "true",
-		},
+		configsMap[config.GetName()] = config.GetValue()
 	}
+	var channelBindings any = confluentBinding{configsMap}
 	messageBindings := spec.MessageBindingsObject{Kafka: &spec.KafkaMessage{Key: &spec.KafkaMessageKey{Schema: map[string]any{"type": "string"}}}}
 	operationBindings := spec.OperationBindingsObject{Kafka: &spec.KafkaOperation{
 		GroupID:  &spec.KafkaOperationGroupID{Schema: map[string]any{"type": "string"}},
@@ -323,17 +300,12 @@ func (c *command) getBindings(cluster *ccstructs.KafkaCluster, topicDescription
 		messageBinding:   messageBindings,
 		operationBinding: operationBindings,
 	}
-	if deleteRetentionMsValue != -1 && cleanupPolicy != "" {
-		bindings.channelBindings = spec.ChannelBindingsObject{Kafka: &channelBindings}
-	}
+	bindings.channelBindings = spec.ChannelBindingsObject{Kafka: &channelBindings}
+
 	return bindings, nil
 }
 
 func (c *command) getClusterDetails(details *accountDetails, flags *flags) error {
-	cluster, err := dynamicconfig.KafkaCluster(c.Context)
-	if err != nil {
-		return fmt.Errorf(`failed to find Kafka cluster: %v`, err)
-	}
 	clusterConfig, err := c.Context.GetKafkaClusterForCommand()
 	if err != nil {
 		return fmt.Errorf(`failed to find Kafka cluster: %v`, err)
@@ -356,12 +328,12 @@ func (c *command) getClusterDetails(details *accountDetails, flags *flags) error
 	if err != nil {
 		return err
 	}
-	topics, httpResp, err := kafkaREST.CloudClient.ListKafkaTopics(cluster.GetId())
+	topics, httpResp, err := kafkaREST.CloudClient.ListKafkaTopics(clusterConfig.ID)
 	if err != nil {
 		return kafkarest.NewError(kafkaREST.CloudClient.GetUrl(), err, httpResp)
 	}
 
-	details.cluster = cluster
+	details.clusterId = clusterConfig.ID
 	details.topics = topics.Data
 	details.clusterCreds = clusterCreds
 	details.broker = kafkaREST.CloudClient.GetUrl()
@@ -486,7 +458,7 @@ func getMessageCompatibility(srClient *schemaregistry.APIClient, ctx context.Con
 	mapOfMessageCompat := make(map[string]any)
 	config, _, err := srClient.DefaultApi.GetSubjectLevelConfig(ctx, subject, nil)
 	if err != nil {
-		log.CliLogger.Warnf("failed to get subject level configuration: %v", err)
+		log.CliLogger.Warnf("Failed to get subject level configuration: %v", err)
 		config, _, err = srClient.DefaultApi.GetTopLevelConfig(ctx)
 		if err != nil {
 			return nil, fmt.Errorf("failed to get top level configuration: %v", err)
