@@ -46,7 +46,12 @@ func (c *clusterCommand) list(cmd *cobra.Command, _ []string) error {
 			clusters = append(clusters, clustersOfEnvironment...)
 		}
 	} else {
-		clusters, err = c.V2Client.ListKafkaClusters(c.EnvironmentId())
+		environmentId, err := c.EnvironmentId()
+		if err != nil {
+			return err
+		}
+
+		clusters, err = c.V2Client.ListKafkaClusters(environmentId)
 		if err != nil {
 			return err
 		}
